import sys
from app.cli import main

if __name__ == "__main__":
    # Appelle la fonction main() de cli.py en passant les arguments de ligne de commande
    # Cela permet de lancer l'application en utilisant un fichier de configuration
    main()